bayespy.inference.vmp.nodes.gaussian.GaussianGammaISOToGaussianGammaARD.has_plotter
===================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaISOToGaussianGammaARD.has_plotter